@@ -1,5 +1,5 @@
 import aiohttp
-from.urllib.request import urlopen
+from urllib.request import urlopen
 
 url = None
 qq = None
@@ -12,9 +12,9 @@ class Country:
 		url = f"https://disease.sh/v2/countries/{self.country}"
 		async with aiohttp.ClientSession() as session:
 			async with session.get(url) as resp:
-				data = resp.json()
+				shit = resp.json()
 		global data
-		data = qq.json()
+		data = shit
 	def total_cases(self):
 		global data
 		cases = convert(int(data["cases"]))
